@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package AnyEvent::CurrentCost;
 BEGIN {
-  $AnyEvent::CurrentCost::VERSION = '1.110791';
+  $AnyEvent::CurrentCost::VERSION = '1.110792';
 }
 
 # ABSTRACT: AnyEvent module for reading from Current Cost energy meters
@@ -62,7 +62,7 @@ sub _setup_handle {
                             my $rbuf = \$handle->{rbuf};
                             carp $handle, ": Discarding '", $$rbuf, "'\n";
                             $$rbuf = '';
-                            $handle->rtimeout(0);
+                            $handle->rtimeout(undef);
                           }),
                          );
   $self->{handle} = $handle;
@@ -85,9 +85,9 @@ sub anyevent_read_type {
     while (1) { # read all message from the buffer
       print STDERR "Before: ", (unpack 'H*', $$rbuf||''), "\n" if DEBUG;
       my $res = $self->read_one($rbuf);
-      $handle->rtimeout($self->{discard_timeout}) if ($$rbuf && length $$rbuf);
       return unless ($res);
       print STDERR "After: ", (unpack 'H*', $$rbuf), "\n" if DEBUG;
+      $handle->rtimeout($self->{discard_timeout}) if ($$rbuf && length $$rbuf);
       $res = $cb->($res) and return $res;
     }
   }
@@ -104,7 +104,7 @@ AnyEvent::CurrentCost - AnyEvent module for reading from Current Cost energy met
 
 =head1 VERSION
 
-version 1.110791
+version 1.110792
 
 =head1 SYNOPSIS
 
